# -*- coding: utf-8; tab-width: 4; indent-tabs-mode: nil -*-
#
# Copyright (C) 2009 - Jeremy AustinBardo <ausimage@ubuntu.com>;
#    Adam J. Lincoln <adamjlincoln@gmail.com>
# Copyright (C) 2006 - Florian Ludwig <dino@phidev.info>;
#   Franz Pletz <fpletz@franz-pletz.org>
#
# Apt-zeroconf is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Apt-zeroconf is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with apt-zeroconf; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
"""
Main Initialization Module for apt-zeroconf which loads the necessary services.

@requires: logging
@requires: L{aptzeroconf.avaphi.AZCAvahiService}
@requires: L{aptzeroconf.http.HttpServer}
@requires: L{aptzeroconf.apt.pkglist}
@requires: L{aptzeroconf.apt.apt_watcher}
@requires: L{aptzeroconf.config.config}
"""
__version__ = '0.5.1'

import logging

LEVELS = {'debug': logging.DEBUG, 'info': logging.INFO,
            'warning': logging.WARNING, 'error': logging.ERROR,
            'critical': logging.CRITICAL}
    
def main(option=None):
    """
    Initialize services for apt-zeroconf. ZeroConf, Package monitor, and
    Proxy Server.

    @requires: aptzeroconf.avaphi.AZCAvahiService
    @requires: aptzeroconf.http.HttpServer
    @requires: aptzeroconf.apt.apt_watcher
    @requires: aptzeroconf.config.config
    """
    #{ Command line logger overide for standard INFO level logging
    loglevel = logging.INFO
    if  hasattr(option,'logger') and option.logger:
        loglevel = LEVELS.get(option.logger.strip().lower(), loglevel)
     
    logging.basicConfig(level=loglevel,
        format='%(asctime)s [%(threadName)s] [%(levelname)-7s] %(message)s',
        datefmt='%Y-%m-%d %H:%M:%S'
        )

    from aptzeroconf.avaphi import AZCAvahiService
    from aptzeroconf.http import HttpServer
    from aptzeroconf.apt import apt_watcher
    from aptzeroconf.config import config
    
    #{ Command line port override, sets new port number
    if  hasattr(option,'port') and option.port.isdigit():
        config.set('http_port', option.port)

    #{ Command line proxy override, turns on restricted proxt
    if  hasattr(option,'restrict') and option.restrict:
        config.set('restrict', 'on')
    
   


    #{ Kick off the httpd
    logging.debug('apt-zeroconf %s' % __version__)
    logging.debug('Starting httpd on port %i.' % config['http_port'])
    httpd = HttpServer()

    #{ Initialize Avahi
    srv = AZCAvahiService()
    srv.start()

    apt_watcher.start()

    try:
        httpd.serve_forever()
    except KeyboardInterrupt:
        logging.info('Signal received, terminating.')

    httpd.server_close()
    apt_watcher.stop()
    srv.stop()


if __name__ == '__main__':
    main()

